@@ -1,5 +1,5 @@
 /* Data structures and API for location specs in GDB.
-   Copyright (C) 2013-2022 Free Software Foundation, Inc.
+   Copyright (C) 2013-2026 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -16,7 +16,6 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#include "defs.h"
 #include "gdbsupport/gdb_assert.h"
 #include "gdbsupport/gdb-checked-static-cast.h"
 #include "location.h"
@@ -27,7 +26,6 @@
 #include "probe.h"
 #include "cp-support.h"
 
-#include <ctype.h>
 #include <string.h>
 
 static std::string
@@ -79,19 +77,14 @@ linespec_location_spec::linespec_location_spec
       p = remove_trailing_whitespace (orig, *linespec);
 
       /* If there is no valid linespec then this will leave the
-	 spec_string as nullptr.  This behaviour is relied on in the
+	 spec_string as nullptr.  This behavior is relied on in the
 	 breakpoint setting code, where spec_string being nullptr means
 	 to use the default breakpoint location.  */
       if ((p - orig) > 0)
-	spec_string = savestring (orig, p - orig);
+	spec_string.reset (savestring (orig, p - orig));
     }
 }
 
-linespec_location_spec::~linespec_location_spec ()
-{
-  xfree (spec_string);
-}
-
 location_spec_up
 linespec_location_spec::clone () const
 {
@@ -108,7 +101,7 @@ linespec_location_spec::linespec_location_spec
   (const linespec_location_spec &other)
   : location_spec (other),
     match_type (other.match_type),
-    spec_string (maybe_xstrdup (other.spec_string))
+    spec_string (maybe_xstrdup (other.spec_string.get ()))
 {
 }
 
@@ -118,9 +111,9 @@ linespec_location_spec::compute_string () const
   if (spec_string != nullptr)
     {
       if (match_type == symbol_name_match_type::FULL)
-	return std::string ("-qualified ") + spec_string;
+	return std::string ("-qualified ") + spec_string.get ();
       else
-	return spec_string;
+	return spec_string.get ();
     }
   return {};
 }
@@ -161,25 +154,19 @@ address_location_spec::compute_string () const
   return std::string ("*") + addr_string;
 }
 
-explicit_location_spec::explicit_location_spec ()
-  : location_spec (EXPLICIT_LOCATION_SPEC)
+explicit_location_spec::explicit_location_spec (const char *function_name)
+  : location_spec (EXPLICIT_LOCATION_SPEC),
+    function_name (maybe_xstrdup (function_name))
 {
 }
 
-explicit_location_spec::~explicit_location_spec ()
-{
-  xfree (source_filename);
-  xfree (function_name);
-  xfree (label_name);
-}
-
 explicit_location_spec::explicit_location_spec
   (const explicit_location_spec &other)
   : location_spec (other),
-    source_filename (maybe_xstrdup (other.source_filename)),
-    function_name (maybe_xstrdup (other.function_name)),
+    source_filename (maybe_xstrdup (other.source_filename.get ())),
+    function_name (maybe_xstrdup (other.function_name.get ())),
     func_name_match_type (other.func_name_match_type),
-    label_name (maybe_xstrdup (other.label_name)),
+    label_name (maybe_xstrdup (other.label_name.get ())),
     line_offset (other.line_offset)
 {
 }
@@ -296,7 +283,7 @@ explicit_to_string_internal (bool as_linespec,
     {
       if (!as_linespec)
 	buf.puts ("-source ");
-      buf.puts (explicit_loc->source_filename);
+      buf.puts (explicit_loc->source_filename.get ());
       need_space = true;
     }
 
@@ -308,7 +295,7 @@ explicit_to_string_internal (bool as_linespec,
 	buf.puts ("-qualified ");
       if (!as_linespec)
 	buf.puts ("-function ");
-      buf.puts (explicit_loc->function_name);
+      buf.puts (explicit_loc->function_name.get ());
       need_space = true;
     }
 
@@ -318,7 +305,7 @@ explicit_to_string_internal (bool as_linespec,
 	buf.putc (space);
       if (!as_linespec)
 	buf.puts ("-label ");
-      buf.puts (explicit_loc->label_name);
+      buf.puts (explicit_loc->label_name.get ());
       need_space = true;
     }
 
@@ -420,15 +407,15 @@ explicit_location_spec_lex_one (const char **inp,
      whitespace or comma.  */
   if (*start == '-' || *start == '+')
     {
-      while (*inp[0] != '\0' && *inp[0] != ',' && !isspace (*inp[0]))
+      while (*inp[0] != '\0' && *inp[0] != ',' && !c_isspace (*inp[0]))
 	++(*inp);
     }
   else
     {
       /* Handle numbers first, stopping at the next whitespace or ','.  */
-      while (isdigit (*inp[0]))
+      while (c_isdigit (*inp[0]))
 	++(*inp);
-      if (*inp[0] == '\0' || isspace (*inp[0]) || *inp[0] == ',')
+      if (*inp[0] == '\0' || c_isspace (*inp[0]) || *inp[0] == ',')
 	return gdb::unique_xmalloc_ptr<char> (savestring (start,
 							  *inp - start));
 
@@ -437,7 +424,7 @@ explicit_location_spec_lex_one (const char **inp,
       *inp = start;
       while ((*inp)[0]
 	     && (*inp)[0] != ','
-	     && !(isspace ((*inp)[0])
+	     && !(c_isspace ((*inp)[0])
 		  || linespec_lexer_lex_keyword (&(*inp)[1])))
 	{
 	  /* Special case: C++ operator,.  */
@@ -466,14 +453,14 @@ is_cp_operator (const char *start, const char *comma)
     {
       const char *p = comma;
 
-      while (p > start && isspace (p[-1]))
+      while (p > start && c_isspace (p[-1]))
 	p--;
       if (p - start >= CP_OPERATOR_LEN)
 	{
 	  p -= CP_OPERATOR_LEN;
 	  if (strncmp (p, CP_OPERATOR_STR, CP_OPERATOR_LEN) == 0
 	      && (p == start
-		  || !(isalnum (p[-1]) || p[-1] == '_')))
+		  || !(c_isalnum (p[-1]) || p[-1] == '_')))
 	    {
 	      return true;
 	    }
@@ -636,7 +623,7 @@ string_to_explicit_location_spec (const char **argp,
   if (argp == NULL
       || *argp == NULL
       || *argp[0] != '-'
-      || !isalpha ((*argp)[1])
+      || !c_isalpha ((*argp)[1])
       || ((*argp)[0] == '-' && (*argp)[1] == 'p'))
     return NULL;
 
@@ -710,13 +697,13 @@ string_to_explicit_location_spec (const char **argp,
 	{
 	  set_oarg (explicit_location_spec_lex_one (argp, language,
 						    completion_info));
-	  locspec->source_filename = oarg.release ();
+	  locspec->source_filename = std::move (oarg);
 	}
       else if (strncmp (opt.get (), "-function", len) == 0)
 	{
 	  set_oarg (explicit_location_spec_lex_one_function (argp, language,
 							     completion_info));
-	  locspec->function_name = oarg.release ();
+	  locspec->function_name = std::move (oarg);
 	}
       else if (strncmp (opt.get (), "-qualified", len) == 0)
 	{
@@ -736,11 +723,11 @@ string_to_explicit_location_spec (const char **argp,
 	{
 	  set_oarg (explicit_location_spec_lex_one (argp, language,
 						    completion_info));
-	  locspec->label_name = oarg.release ();
+	  locspec->label_name = std::move (oarg);
 	}
       /* Only emit an "invalid argument" error for options
 	 that look like option strings.  */
-      else if (opt.get ()[0] == '-' && !isdigit (opt.get ()[1]))
+      else if (opt.get ()[0] == '-' && !c_isdigit (opt.get ()[1]))
 	{
 	  if (completion_info == NULL)
 	    error (_("invalid explicit location argument, \"%s\""), opt.get ());
