@@ -18,16 +18,7 @@
 #include <hip/hip_runtime.h>
 #include <unistd.h>
 
-#define CHECK(cmd)                                                           \
-  {                                                                          \
-    hipError_t error = cmd;                                                  \
-    if (error != hipSuccess)                                                 \
-      {                                                                      \
-	fprintf (stderr, "error: '%s'(%d) at %s:%d\n",                       \
-		 hipGetErrorString (error), error, __FILE__, __LINE__);      \
-	exit (EXIT_FAILURE);                                                 \
-      }                                                                      \
-  }
+#include "rocm-test-utils.h"
 
 __global__ static void
 kernel1 ()
